aboutsummaryrefslogtreecommitdiffstats
path: root/packages/0x.js/src/contract_wrappers/token_wrapper.ts
diff options
context:
space:
mode:
authorLeonid Logvinov <logvinov.leon@gmail.com>2017-12-18 22:35:23 +0800
committerLeonid Logvinov <logvinov.leon@gmail.com>2017-12-19 19:10:43 +0800
commit1e4fdcf615502478cbec8711bf6710e093c0c279 (patch)
treec31e798244f261bba623235baaf2873d7df3daf6 /packages/0x.js/src/contract_wrappers/token_wrapper.ts
parentc63f76dde7267c54328d2f12f401d94484e5a91a (diff)
downloaddexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.tar
dexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.tar.gz
dexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.tar.bz2
dexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.tar.lz
dexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.tar.xz
dexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.tar.zst
dexon-0x-contracts-1e4fdcf615502478cbec8711bf6710e093c0c279.zip
Rename SubscriptionOpts to BlockRange
Diffstat (limited to 'packages/0x.js/src/contract_wrappers/token_wrapper.ts')
-rw-r--r--packages/0x.js/src/contract_wrappers/token_wrapper.ts10
1 files changed, 5 insertions, 5 deletions
diff --git a/packages/0x.js/src/contract_wrappers/token_wrapper.ts b/packages/0x.js/src/contract_wrappers/token_wrapper.ts
index eccb74871..419b33285 100644
--- a/packages/0x.js/src/contract_wrappers/token_wrapper.ts
+++ b/packages/0x.js/src/contract_wrappers/token_wrapper.ts
@@ -5,11 +5,11 @@ import * as _ from 'lodash';
import {artifacts} from '../artifacts';
import {
+ BlockRange,
EventCallback,
IndexedFilterValues,
LogWithDecodedArgs,
MethodOpts,
- SubscriptionOpts,
TokenContractEventArgs,
TokenEvents,
TransactionOpts,
@@ -291,20 +291,20 @@ export class TokenWrapper extends ContractWrapper {
* Gets historical logs without creating a subscription
* @param tokenAddress An address of the token that emmited the logs.
* @param eventName The token contract event you would like to subscribe to.
* @param subscriptionOpts Subscriptions options that let you configure the subscription.
* @param indexFilterValues An object where the keys are indexed args returned by the event and
* the value is the value you are interested in. E.g `{_from: aUserAddressHex}`
* @return Array of logs that match the parameters
*/
public async getLogsAsync<ArgsType extends TokenContractEventArgs>(
- tokenAddress: string, eventName: TokenEvents, subscriptionOpts: SubscriptionOpts,
+ tokenAddress: string, eventName: TokenEvents, blockRange: BlockRange,
indexFilterValues: IndexedFilterValues): Promise<Array<LogWithDecodedArgs<ArgsType>>> {
assert.isETHAddressHex('tokenAddress', tokenAddress);
assert.doesBelongToStringEnum('eventName', eventName, TokenEvents);
- assert.doesConformToSchema('subscriptionOpts', subscriptionOpts, schemas.subscriptionOptsSchema);
+ assert.doesConformToSchema('blockRange', blockRange, schemas.blockRangeSchema);
assert.doesConformToSchema('indexFilterValues', indexFilterValues, schemas.indexFilterValuesSchema);
const logs = await this._getLogsAsync<ArgsType>(
- tokenAddress, eventName, subscriptionOpts, indexFilterValues, artifacts.TokenArtifact.abi,
+ tokenAddress, eventName, blockRange, indexFilterValues, artifacts.TokenArtifact.abi,
);
return logs;
}
@@ -291,20 +291,20 @@ export class TokenWrapper extends ContractWrapper {
* @param tokenAddress An address of the token that emmited the logs.
* @param eventName The token contract event you would like to subscribe to.
- * @param subscriptionOpts Subscriptions options that let you configure the subscription.
+ * @param blockRange Subscriptions options that let you configure the subscription.
* @param indexFilterValues An object where the keys are indexed args returned by the event and
* the value is the value you are interested in. E.g `{_from: aUserAddressHex}`